XVPoint class

Represents a 2D point with integer coordinates.

This value object is used to specify pixel locations, drawing coordinates, and geometric endpoints.

Constructors

XVPoint(int x, int y)
Creates an XVPoint with the specified integer coordinates.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
x int
The X-coordinate (column index) of the point.
final
y int
The Y-coordinate (row index) of the point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited