XVRect class

Represents a 2D axis-aligned rectangle with integer coordinates.

This value object is used to define image regions of interest (ROI), crop zones, bounding boxes, or sub-regions.

Constructors

XVRect(int x, int y, int width, int height)
Creates an XVRect with the specified coordinates and size.
const

Properties

bottom int
The bottom edge Y-coordinate.
no setter
bottomRight XVPoint
The bottom-right corner as an XVPoint.
no setter
hashCode int
The hash code for this object.
no setterinherited
height int
The height of the rectangle in pixels.
final
left int
The left edge X-coordinate (alias for x).
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
The right edge X-coordinate.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
top int
The top edge Y-coordinate (alias for y).
no setter
topLeft XVPoint
The top-left corner as an XVPoint.
no setter
width int
The width of the rectangle in pixels.
final
x int
The X-coordinate (column offset) of the top-left corner.
final
y int
The Y-coordinate (row offset) of the top-left corner.
final

Methods

contains(XVPoint point) bool
Checks if point is inside the boundaries of this rectangle.
intersect(XVRect other) XVRect
Calculates the intersecting region with other rectangle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
union(XVRect other) XVRect
Calculates the union region containing both this and the other rectangle.

Operators

operator ==(Object other) bool
The equality operator.
inherited