XVRotatedRect class

Represents a rotated rectangle on a 2D plane.

Defined by a center point, width/height size, and a clockwise rotation angle in degrees. Often used in computer vision for rotated bounding box annotations.

Constructors

XVRotatedRect(XVPointF center, XVSize size, double angle)
Creates an XVRotatedRect with center, size, and rotation angle.
const

Properties

angle double
The clockwise rotation angle in degrees.
final
center XVPointF
The center point of the rotated rectangle.
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size XVSize
The width and height of the rectangle.
final
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited