XVUnsupportedFormatException class

Thrown when a format is not supported by an operation.

This exception occurs when attempting to run an operation (such as a specific color space conversion or filter) on an incompatible pixel format.

Inheritance

Constructors

XVUnsupportedFormatException({required String operation, required String message, dynamic expected, dynamic actual})
Creates an XVUnsupportedFormatException instance.
const

Properties

actual → dynamic
The actual invalid value encountered (optional).
finalinherited
expected → dynamic
The expected value or constraint (optional).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The detailed error message.
finalinherited
operation String
The operation name where the exception occurred.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited