XVPointF class
Represents a 2D point with floating-point coordinates.
This value object is used for sub-pixel accuracy operations, such as arbitrary rotations, letterboxing ratios, or CNN model coordinate mapping.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - x → double
-
The X-coordinate of the point.
final
- y → double
-
The Y-coordinate of the point.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited